@@ -49,6 +49,7 @@
 #define HAVE_GMP_H 1
 #define HAVE_LIBGMP 1
 #define HAVE_TYPEOF 1
+#define restrict __restrict__
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
 #define SIZEOF_INT 4
@@ -142,6 +143,7 @@
 #define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
 #define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
+#define RUBY_CXX_DEPRECATED(msg) __attribute__((__deprecated__(msg)))
 #define FUNC_STDCALL(x) __attribute__ ((__stdcall__)) x
 #define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define FUNC_FASTCALL(x) __attribute__ ((__fastcall__)) x
@@ -152,6 +154,7 @@
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
 #define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
+#define RUBY_FUNC_NONNULL(n,x) __attribute__ ((__nonnull__(n))) x
 #define RUBY_FUNCTION_NAME_STRING __func__
 #define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
@@ -216,11 +219,8 @@
 #define HAVE_ERF 1
 #define HAVE_EXPLICIT_BZERO 1
 #define HAVE_FFS 1
-#define HAVE_FINITE 1
 #define HAVE_FLOCK 1
 #define HAVE_HYPOT 1
-#define HAVE_ISINF 1
-#define HAVE_ISNAN 1
 #define HAVE_LGAMMA_R 1
 #define HAVE_MEMMOVE 1
 #define HAVE_NAN 1
@@ -232,6 +232,9 @@
 #define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_TGAMMA 1
+#define HAVE_FINITE 1
+#define HAVE_ISINF 1
+#define HAVE_ISNAN 1
 #define HAVE_SIGNBIT 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -266,15 +269,10 @@
 #define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
-#define HAVE_GETLOGIN 1
-#define HAVE_GETLOGIN_R 1
 #define HAVE_GETPGID 1
 #define HAVE_GETPGRP 1
 #define HAVE_GETPRIORITY 1
-#define HAVE_GETPWNAM 1
 #define HAVE_GETPWNAM_R 1
-#define HAVE_GETPWUID 1
-#define HAVE_GETPWUID_R 1
 #define HAVE_GETRESGID 1
 #define HAVE_GETRESUID 1
 #define HAVE_GETRLIMIT 1
@@ -307,6 +305,7 @@
 #define HAVE_PREAD 1
 #define HAVE_PWRITE 1
 #define HAVE_READLINK 1
+#define HAVE_REALPATH 1
 #define HAVE_ROUND 1
 #define HAVE_SEEKDIR 1
 #define HAVE_SETEGID 1
@@ -373,6 +372,7 @@
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
+#define COROUTINE_H "coroutine/x86/Context.h"
 #define _REENTRANT 1
 #define _THREAD_SAFE 1
 #define HAVE_LIBPTHREAD 1
@@ -397,9 +397,8 @@
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
 #define HAVE_SIGSETJMP 1
-#define RUBY_SETJMP(env) _setjmp((env))
-#define RUBY_LONGJMP(env,val) _longjmp((env),val)
-#define RUBY_JMP_BUF jmp_buf
+#define RUBY_SETJMP(env) __builtin_setjmp((void **)(env))
+#define RUBY_LONGJMP(env,val) __builtin_longjmp((void **)(env),val)
 #define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "i386-openbsd"
