@@ -32,7 +32,6 @@
 #define HAVE_LIMITS_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_PWD_H 1
-#define HAVE_STDALIGN_H 1
 #define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
@@ -49,6 +48,7 @@
 #define HAVE_GMP_H 1
 #define HAVE_LIBGMP 1
 #define HAVE_TYPEOF 1
+#define restrict __restrict__
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
 #define SIZEOF_INT 4
@@ -56,7 +56,7 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
-#define SIZEOF___INT128 16
+#define SIZEOF___INT128 0
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -126,29 +126,25 @@
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
 #define RUBY_ALIGNAS(x) __attribute__((__aligned__(x)))
-#define RUBY_ALIGNOF alignof
+#define RUBY_ALIGNOF __alignof
 #define CONSTFUNC(x) __attribute__ ((__const__)) x
 #define PUREFUNC(x) __attribute__ ((__pure__)) x
 #define NORETURN(x) __attribute__ ((__noreturn__)) x
 #define DEPRECATED(x) __attribute__ ((__deprecated__)) x
-#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
-#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
+#define DEPRECATED_TYPE(mesg,x) __attribute__ ((__deprecated__ mesg)) x
 #define NOINLINE(x) __attribute__ ((__noinline__)) x
 #define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
-#define NO_SANITIZE(san, x) __attribute__ ((__no_sanitize__(san))) x
-#define NO_SANITIZE_ADDRESS(x) __attribute__ ((__no_sanitize_address__)) x
-#define NO_ADDRESS_SAFETY_ANALYSIS(x) __attribute__ ((__no_address_safety_analysis__)) x
 #define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
 #define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
 #define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
-#define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
-#define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
+#define RUBY_FUNC_NONNULL(n,x) __attribute__ ((__nonnull__(n))) x
+#define RUBY_FUNCTION_NAME_STRING __func__
 #define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DECL_GETENV 1
@@ -195,12 +191,6 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
-#define HAVE_INT128_T 1
-#define int128_t __int128
-#define SIZEOF_INT128_T SIZEOF___INT128
-#define HAVE_UINT128_T 1
-#define uint128_t unsigned __int128
-#define SIZEOF_UINT128_T SIZEOF___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -218,11 +208,8 @@
 #define HAVE_ERF 1
 #define HAVE_EXPLICIT_BZERO 1
 #define HAVE_FFS 1
-#define HAVE_FINITE 1
 #define HAVE_FLOCK 1
 #define HAVE_HYPOT 1
-#define HAVE_ISINF 1
-#define HAVE_ISNAN 1
 #define HAVE_LGAMMA_R 1
 #define HAVE_MEMMOVE 1
 #define HAVE_NAN 1
@@ -234,6 +221,9 @@
 #define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_TGAMMA 1
+#define HAVE_FINITE 1
+#define HAVE_ISINF 1
+#define HAVE_ISNAN 1
 #define HAVE_SIGNBIT 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -268,15 +258,10 @@
 #define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
-#define HAVE_GETLOGIN 1
-#define HAVE_GETLOGIN_R 1
 #define HAVE_GETPGID 1
 #define HAVE_GETPGRP 1
 #define HAVE_GETPRIORITY 1
-#define HAVE_GETPWNAM 1
 #define HAVE_GETPWNAM_R 1
-#define HAVE_GETPWUID 1
-#define HAVE_GETPWUID_R 1
 #define HAVE_GETRESGID 1
 #define HAVE_GETRESUID 1
 #define HAVE_GETRLIMIT 1
@@ -309,6 +294,7 @@
 #define HAVE_PREAD 1
 #define HAVE_PWRITE 1
 #define HAVE_READLINK 1
+#define HAVE_REALPATH 1
 #define HAVE_ROUND 1
 #define HAVE_SEEKDIR 1
 #define HAVE_SETEGID 1
@@ -343,11 +329,6 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
-#define HAVE_BUILTIN___BUILTIN_ALLOCA_WITH_ALIGN 1
-#define HAVE_BUILTIN___BUILTIN_ASSUME_ALIGNED 1
-#define HAVE_BUILTIN___BUILTIN_BSWAP16 1
-#define HAVE_BUILTIN___BUILTIN_BSWAP32 1
-#define HAVE_BUILTIN___BUILTIN_BSWAP64 1
 #define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
 #define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
@@ -355,12 +336,8 @@
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CTZ 1
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
-#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
-#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define ATAN2_INF_C99 1
@@ -375,6 +352,7 @@
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
+#define COROUTINE_H "coroutine/copy/Context.h"
 #define _REENTRANT 1
 #define _THREAD_SAFE 1
 #define HAVE_LIBPTHREAD 1
