@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.6.") or
-    raise "ruby lib version (2.6.8) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.7.") or
+    raise "ruby lib version (2.7.1) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.6/sparc64-openbsd")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.7/sparc64-openbsd")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "8"
-  CONFIG["PATCHLEVEL"] = "205"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.6.8/bin/install -c'
+  CONFIG["MINOR"] = "7"
+  CONFIG["TEENY"] = "1"
+  CONFIG["PATCHLEVEL"] = "83"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.7.1/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)26"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)26"
-  CONFIG["RUBY_SO_NAME"] = "ruby26"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)27"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)27"
+  CONFIG["RUBY_SO_NAME"] = "ruby27"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.6.pc"
+  CONFIG["ruby_pc"] = "ruby-2.7.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -44,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--program-suffix=26' '--with-soname=ruby26' '--with-ruby-version=minor' '--with-mantype=doc' '--with-setjmp-type=_setjmp' '--enable-pthread' '--enable-ipv6' '--without-bundled-libffi' '--disable-option-checking' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe -std=gnu99' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--enable-shared' '--program-suffix=27' '--with-soname=ruby27' '--with-ruby-version=minor' '--with-mantype=doc' '--enable-pthread' '--enable-ipv6' '--without-bundled-libffi' '--disable-option-checking' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -54,7 +54,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.6"
+  CONFIG["ruby_version"] = "2.7"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "sparc64-openbsd"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -95,7 +95,7 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeclaration-after-statement -Wdeprecated-declarations -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
@@ -149,9 +149,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.6.8/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.6.8/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.6.8/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.7.1/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.7.1/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.7.1/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -167,7 +167,7 @@ module RbConfig
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION_MESSAGE"] = "cc (GCC) 4.2.1 20070719 \nCopyright (C) 2007 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/usr/bin/cc"
+  CONFIG["MJIT_CC"] = "/usr/bin/cc -std=gnu99"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
@@ -183,28 +183,28 @@ module RbConfig
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -fstack-protector-strong -Wl,-E"
-  CONFIG["CFLAGS"] = "-O2 -pipe -std=gnu99 -fPIC"
-  CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd7.0"
+  CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
+  CONFIG["CC"] = "cc -std=gnu99"
+  CONFIG["target_os"] = "openbsd6.8"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "sparc64"
-  CONFIG["target"] = "sparc64-unknown-openbsd7.0"
-  CONFIG["host_os"] = "openbsd7.0"
+  CONFIG["target"] = "sparc64-unknown-openbsd6.8"
+  CONFIG["host_os"] = "openbsd6.8"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "sparc64"
-  CONFIG["host"] = "sparc64-unknown-openbsd7.0"
+  CONFIG["host"] = "sparc64-unknown-openbsd6.8"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd7.0"
+  CONFIG["build_os"] = "openbsd6.8"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "sparc64"
-  CONFIG["build"] = "sparc64-unknown-openbsd7.0"
+  CONFIG["build"] = "sparc64-unknown-openbsd6.8"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.6.8"
   CONFIG["HAVE_GIT"] = "no"
   CONFIG["GIT"] = "git"
-  CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
@@ -235,7 +235,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&26&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&27&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -246,7 +246,7 @@ module RbConfig
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
   CONFIG["UNICODE_VERSION"] = "12.1.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "12.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "12.1"
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
@@ -323,7 +323,7 @@ module RbConfig
   #
   # returns updated keys list, or +nil+ if nothing changed.
   def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG)
-    return if (old = mkconf[key]) == val
+    return if mkconf[key] == val
     mkconf[key] = val
     keys = [key]
     deps = []
